@@ -10,7 +10,7 @@ from jinja2 import FileSystemLoader
 from nose.exc import SkipTest
 from nose.plugins import Plugin
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 
 TEST_ID = re.compile(r'^(.*?)(\(.*\))$')
 
@@ -140,7 +140,12 @@ class HtmlOutput(Plugin):
     def addError(self, test, err, capt=None):
         """Add error output to Xunit report.
         """
-        tb = ''.join(traceback.format_exception(*err))
+        exc_type, exc_val, tb = err
+        tb = ''.join(traceback.format_exception(
+            exc_type,
+            exc_val if isinstance(exc_val, exc_type) else exc_type(exc_val),
+            tb
+        ))
         name = id_split(test.id())
         group = self.report_data[name[0]]
         if issubclass(err[0], SkipTest):
@@ -160,7 +165,7 @@ class HtmlOutput(Plugin):
             'tb': tb,
         })
 
-    def addFailure(self, test, err, capt=None, tb_info=None):
+    def addFailure(self, test, err, capt=None):
         """Add failure output to Xunit report.
         """
         exc_type, exc_val, tb = err
